@@ -267,5 +267,19 @@ class Client(object):
         self.logger.info("Resuming campaign %s" % CampaignID)
         self.call_method("ResumeCampaign", {"CampaignID": CampaignID})
 
+    def StopBanners(self, CampaignID, BannerIDS):
+        self.logger.info("Stopping banners %s" % BannerIDS)
+        self.call_method("StopBanners", {
+            "CampaignID": CampaignID,
+            "BannerIDS": BannerIDS,
+        })
+
+    def ResumeBanners(self, CampaignID, BannerIDS):
+        self.logger.info("Resuming banners %s" % BannerIDS)
+        self.call_method("ResumeBanners", {
+            "CampaignID": CampaignID,
+            "BannerIDS": BannerIDS,
+        })
+
     def GetCampaignParams(self, CampaignID):
         return self.call_method("GetCampaignParams", {"CampaignID": CampaignID})
